Block class

A block

Annotations
  • @JsonSerializable.new()

Constructors

Block({required String blockhash, required String previousBlockhash, required int parentSlot, required List<Transaction> transactions, required Meta? meta, required List<String> signatures, required List<Reward> rewards, required int? blockTime, required int? blockHeight})
const
Block.fromJson(Map<String, dynamic> json)
factory

Properties

blockhash → String
The blockhash of this block, as base-58 encoded string
final
blockHeight → int?
The number of blocks beneath this block
final
blockTime → int?
Estimated production time, as Unix timestamp (seconds since the Unix epoch). None if not available.
final
hashCode → int
The hash code for this object.
no setterinherited
meta → Meta?
Transaction status metadata object
final
parentSlot → int
The slot index of this block's parent
final
previousBlockhash → String
The blockhash of this block's parent, as base-58 encoded string; if the parent block is not available due to ledger cleanup, this field will return "11111111111111111111111111111111"
final
rewards → List<Reward>
Present if rewards are requested; an array of Reward objects.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatures → List<String>
Present if TransactionDetailLevel.signatures are requested for transaction details; an array of signatures strings, corresponding to the transaction order in the block.
final
transactions → List<Transaction>
Present if TransactionDetailLevel.full transaction details are requested; an array of Transaction objects
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited