BlockProduction class

A block production

Annotations
  • @JsonSerializable.new()

Constructors

BlockProduction({required Map<String, ByIdentityValue> byIdentity, required Range range})
const
BlockProduction.fromJson(Map<String, dynamic> json)
factory

Properties

byIdentity → Map<String, ByIdentityValue>
A dictionary of validator identities, as base-58 encoded strings. Value is a two element array containing the number of leader slots and the number of blocks produced.
final
hashCode → int
The hash code for this object.
no setterinherited
range → Range
Block production slot range
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited