BlockProductionResult class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

BlockProductionResult({required Context context, required BlockProduction value})
const
BlockProductionResult.fromJson(Map<String, dynamic> json)
factory

Properties

context → Context
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → BlockProduction
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited