ByIdentityValue class

Constructors

ByIdentityValue({required int leaderSlots, required int blocksProduced})
const
ByIdentityValue.fromJson(dynamic data)
factory

Properties

blocksProduced → int
final
hashCode → int
The hash code for this object.
no setterinherited
leaderSlots → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → List<int>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited