InflationRate class

An inflation rate

Annotations
  • @JsonSerializable.new()

Constructors

InflationRate({required double total, required double validator, required double foundation, required double epoch})
const
InflationRate.fromJson(Map<String, dynamic> json)
factory

Properties

epoch → double
Epoch for which these values are valid.
final
foundation → double
Inflation allocated to the foundation.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → double
Total inflation.
final
validator → double
Inflation allocated to validators.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited