InnerInstruction class

List of inner instructions or omitted if inner instruction recording was not yet enabled during this transaction

Annotations
  • @JsonSerializable.new()

Constructors

InnerInstruction({required int index, required List<Instruction> instructions})
const
InnerInstruction.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
Index of the transaction instruction from which the inner instruction(s) originated
final
instructions → List<Instruction>
Ordered list of inner program instructions that were invoked during a single transaction instruction.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited