LatestBlockhash class

A Latest Blockhash

Annotations
  • @JsonSerializable.new()

Constructors

LatestBlockhash({required String blockhash, required int lastValidBlockHeight})
const
LatestBlockhash.fromJson(Map<String, dynamic> json)
factory

Properties

blockhash → String
A Hash as base-58 encoded string accounts
final
hashCode → int
The hash code for this object.
no setterinherited
lastValidBlockHeight → int
Last block height at which the blockhash will be valid
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited