PerfSample class

A performance sample

Annotations
  • @JsonSerializable.new()

Constructors

PerfSample({required int slot, required int numTransactions, required int numSlots, required int samplePeriodSecs})
const
PerfSample.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
numSlots → int
Number of slots in sample.
final
numTransactions → int
Number of transactions in sample.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplePeriodSecs → int
Number of seconds in a sample window.
final
slot → int
Slot in which sample was taken at.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited