Range class

A range of bytes

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Range({required int firstSlot, required int lastSlot})
const
Range.fromJson(Map<String, dynamic> json)
factory

Properties

firstSlot → int
First slot of the block production information (inclusive)
final
hashCode → int
The hash code for this object.
no setterinherited
lastSlot → int
Last slot of block production information (inclusive)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited