Reward class

A reward

Annotations
  • @JsonSerializable.new()

Constructors

Reward({required String pubkey, required int lamports, required int postBalance, required RewardType rewardType, required int commission})
const
Reward.fromJson(Map<String, dynamic> json)
factory

Properties

commission → int
vote account commission when the reward was credited, only present for voting and staking rewards
final
hashCode → int
The hash code for this object.
no setterinherited
lamports → int
Number of reward lamports credited or debited by the account, as a i64.
final
postBalance → int
Account balance in lamports after the reward was applied.
final
pubkey → String
The public key, as base-58 encoded string, of the account that received the reward.
final
rewardType → RewardType
Type of reward
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited