SignatureStatus class

The status of a signature

Annotations
  • @JsonSerializable.new()

Constructors

SignatureStatus({required int slot, required ConfirmationStatus confirmationStatus, int? confirmations, Map<String, dynamic>? err})
const
SignatureStatus.fromJson(Map<String, dynamic> json)
factory

Properties

confirmations → int?
Number of blocks since signature confirmation, null if rooted, as well as finalized.
final
confirmationStatus → ConfirmationStatus
The transaction's cluster confirmation status; either Commitment.processed, Commitment.confirmed, or Commitment.finalized. See Commitment for more on optimistic confirmation.
final
err → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slot → int
The slot the transaction was processed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited