SplTokenAccountDataInfo class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

SplTokenAccountDataInfo({required TokenAmount tokenAmount, required String state, required bool isNative, required String mint, required String owner, String? delegate, TokenAmount? delegateAmount})
const
SplTokenAccountDataInfo.fromJson(Map<String, dynamic> json)
factory

Properties

delegate → String?
final
delegateAmount → TokenAmount?
final
hashCode → int
The hash code for this object.
no setterinherited
isNative → bool
final
mint → String
final
owner → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String
final
tokenAmount → TokenAmount
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited