TokenAmount class

The amount of a SPL token

Annotations
  • @JsonSerializable.new()

Constructors

TokenAmount({required String amount, required int decimals, required String? uiAmountString})
const
TokenAmount.fromJson(Map<String, dynamic> json)
factory

Properties

amount → String
Raw amount of tokens as a string, ignoring decimals.
final
decimals → int
Number of decimals configured for token's mint.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uiAmountString → String?
Token amount as a string, accounting for decimals.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited