TokenBalance class

The balance of a SPL token account

Annotations
  • @JsonSerializable.new()

Constructors

TokenBalance({required int accountIndex, required String mint, required TokenAmount uiTokenAmount})
const
TokenBalance.fromJson(Map<String, dynamic> json)
factory

Properties

accountIndex → int
Index of the account in which the token balance is provided for.
final
hashCode → int
The hash code for this object.
no setterinherited
mint → String
Pubkey of the token's mint.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uiTokenAmount → TokenAmount
Token balance
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited