TransactionMessage class

A transaction message

Annotations
  • @JsonSerializable.new()

Constructors

TransactionMessage({required List<String> accountKeys, required TransactionMessageHeader header, required String recentBlockhash, required List<Instruction> instructions})
const
TransactionMessage.fromJson(Map<String, dynamic> json)
factory

Properties

accountKeys → List<String>
List of base-58 encoded public keys used by the transaction, including by the instructions and for signatures. The first message.header.numRequiredSignatures public keys must sign the transaction.
final
hashCode → int
The hash code for this object.
no setterinherited
Details the account types and signatures required by the transaction.
final
instructions → List<Instruction>
List of program instructions that will be executed in sequence and committed in one atomic transaction if all succeed.
final
recentBlockhash → String
A base-58 encoded hash of a recent block in the ledger used to prevent transaction duplication and to give transactions lifetimes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited